@@ -169,7 +169,7 @@ repo_new_resolve(JSContext *context,
  */
 GJS_NATIVE_CONSTRUCTOR_DECLARE(repo)
 {
-    GJS_NATIVE_CONSTRUCTOR_VARIABLES(repo)
+    JSObject *object = NULL;                            \
     Repo *priv;
 
     GJS_NATIVE_CONSTRUCTOR_PRELUDE(repo);
@@ -222,7 +222,7 @@ static struct JSClass gjs_repo_class = {
     JS_PropertyStub,
     JS_PropertyStub,
     JS_PropertyStub,
-    JS_PropertyStub,
+    JS_StrictPropertyStub,
     JS_EnumerateStub,
     (JSResolveOp) repo_new_resolve, /* needs cast since it's the new resolve signature */
     JS_ConvertStub,
