@@ -45,17 +45,16 @@ static JSBool byte_array_get_prop      (JSContext    *context,
 static JSBool byte_array_set_prop      (JSContext    *context,
                                         JSObject     *obj,
                                         jsid          id,
+#ifdef HAVE_JS_STRICTPROPERTYSTUB
+                                        JSBool        strict,
+#endif
                                         jsval        *value_p);
 static JSBool byte_array_new_resolve   (JSContext    *context,
                                         JSObject     *obj,
                                         jsid          id,
                                         uintN         flags,
                                         JSObject    **objp);
-static JSBool byte_array_constructor   (JSContext    *context,
-                                        JSObject     *obj,
-                                        uintN         argc,
-                                        jsval        *argv,
-                                        jsval        *retval);
+GJS_NATIVE_CONSTRUCTOR_DECLARE(byte_array);
 static void   byte_array_finalize      (JSContext    *context,
                                         JSObject     *obj);
 
@@ -241,6 +240,9 @@ static JSBool
 byte_array_length_setter(JSContext *context,
                          JSObject  *obj,
                          jsid       id,
+#ifdef HAVE_JS_STRICTPROPERTYSTUB
+                         JSBool     strict,
+#endif
                          jsval     *value_p)
 {
     ByteArrayInstance *priv;
@@ -300,6 +302,9 @@ static JSBool
 byte_array_set_prop(JSContext *context,
                     JSObject  *obj,
                     jsid       id,
+#ifdef HAVE_JS_STRICTPROPERTYSTUB
+                    JSBool     strict,
+#endif
                     jsval     *value_p)
 {
     ByteArrayInstance *priv;
@@ -432,13 +437,10 @@ gjs_g_byte_array_new(int preallocated_length)
  * also, but can be replaced with another object to use instead as the
  * prototype.
  */
-static JSBool
-byte_array_constructor(JSContext *context,
-                       JSObject  *obj,
-                       uintN      argc,
-                       jsval     *argv,
-                       jsval     *retval)
+GJS_NATIVE_CONSTRUCTOR_DECLARE(byte_array)
 {
+    JSObject *object = NULL;                            \
+    jsval *argv = JS_ARGV(context, vp);
     ByteArrayInstance *priv;
     JSObject *proto;
     gboolean is_proto;
@@ -446,8 +448,7 @@ byte_array_constructor(JSContext *context,
     JSClass *proto_class;
     gsize preallocated_length;
 
-    if (!gjs_check_constructing(context))
-        return JS_FALSE;
+    GJS_NATIVE_CONSTRUCTOR_PRELUDE(byte_array);
 
     preallocated_length = 0;
     if (argc >= 1) {
@@ -460,17 +461,17 @@ byte_array_constructor(JSContext *context,
 
     priv = g_slice_new0(ByteArrayInstance);
 
-    g_assert(priv_from_js(context, obj) == NULL);
+    g_assert(priv_from_js(context, object) == NULL);
 
-    JS_SetPrivate(context, obj, priv);
+    JS_SetPrivate(context, object, priv);
 
-    proto = JS_GetPrototype(context, obj);
+    proto = JS_GetPrototype(context, object);
 
     /* If we're constructing the prototype, its __proto__ is not the same
      * class as us, but if we're constructing an instance, the prototype
      * has the same class.
      */
-    obj_class = JS_GetClass(context, obj);
+    obj_class = JS_GetClass(context, object);
     proto_class = JS_GetClass(context, proto);
 
     is_proto = (obj_class != proto_class);
@@ -479,6 +480,8 @@ byte_array_constructor(JSContext *context,
         priv->array = gjs_g_byte_array_new(preallocated_length);
     }
 
+    GJS_NATIVE_CONSTRUCTOR_FINISH(byte_array);
+
     return JS_TRUE;
 }
 
@@ -510,7 +513,7 @@ to_string_func(JSContext *context,
     jsval *argv = JS_ARGV(context, vp);
     JSObject *object = JS_THIS_OBJECT(context, vp);
     ByteArrayInstance *priv;
-    const char *encoding;
+    char *encoding;
     gboolean encoding_is_utf8;
 
     priv = priv_from_js(context, object);
@@ -521,7 +524,7 @@ to_string_func(JSContext *context,
     encoding_is_utf8 = TRUE;
     if (argc >= 1 &&
         JSVAL_IS_STRING(argv[0])) {
-        encoding = gjs_string_get_ascii_checked(context, argv[0]);
+        encoding = gjs_string_get_ascii(context, argv[0]);
         if (encoding == NULL)
             return JS_FALSE;
 
@@ -530,6 +533,7 @@ to_string_func(JSContext *context,
          * just an optimization anyway.
          */
         if (strcmp(encoding, "UTF-8") == 0) {
+            g_free(encoding);
             encoding_is_utf8 = TRUE;
         } else {
             encoding_is_utf8 = FALSE;
@@ -567,6 +571,7 @@ to_string_func(JSContext *context,
                            NULL, /* bytes read */
                            &bytes_written,
                            &error);
+        g_free(encoding);
         if (u16_str == NULL) {
             /* frees the GError */
             gjs_throw_g_error(context, error);
@@ -616,7 +621,7 @@ from_string_func(JSContext *context,
 {
     jsval *argv = JS_ARGV(context, vp);
     ByteArrayInstance *priv;
-    const char *encoding;
+    char *encoding;
     gboolean encoding_is_utf8;
     JSObject *obj;
     JSBool retval = JS_FALSE;
@@ -641,7 +646,7 @@ from_string_func(JSContext *context,
     encoding_is_utf8 = TRUE;
     if (argc > 1 &&
         JSVAL_IS_STRING(argv[1])) {
-        encoding = gjs_string_get_ascii_checked(context, argv[1]);
+        encoding = gjs_string_get_ascii(context, argv[1]);
         if (encoding == NULL)
             goto out;
 
@@ -650,6 +655,7 @@ from_string_func(JSContext *context,
          * just an optimization anyway.
          */
         if (strcmp(encoding, "UTF-8") == 0) {
+            g_free(encoding);
             encoding_is_utf8 = TRUE;
         } else {
             encoding_is_utf8 = FALSE;
@@ -679,11 +685,17 @@ from_string_func(JSContext *context,
         char *encoded;
         gsize bytes_written;
         GError *error;
-        jschar *u16_chars;
+        const jschar *u16_chars;
         gsize u16_len;
 
+#ifdef HAVE_JS_GETSTRINGCHARS
         u16_chars = JS_GetStringChars(JSVAL_TO_STRING(argv[0]));
         u16_len = JS_GetStringLength(JSVAL_TO_STRING(argv[0]));
+#else
+        u16_chars = JS_GetStringCharsAndLength(context, JSVAL_TO_STRING(argv[0]), &u16_len);
+        if (u16_chars == NULL)
+            goto out;
+#endif
 
         error = NULL;
         encoded = g_convert((char*) u16_chars,
@@ -693,6 +705,7 @@ from_string_func(JSContext *context,
                             NULL, /* bytes read */
                             &bytes_written,
                             &error);
+        g_free(encoding);
         if (encoded == NULL) {
             /* frees the GError */
             gjs_throw_g_error(context, error);
@@ -807,7 +820,7 @@ gjs_byte_array_from_byte_array (JSContext *context,
     priv = g_slice_new0(ByteArrayInstance);
     g_assert(priv_from_js(context, object) == NULL);
     JS_SetPrivate(context, object, priv);
-    priv->array = g_new(GByteArray, 1);
+    priv->array = g_byte_array_new();
     priv->array->data = g_memdup(array->data, array->len);
     priv->array->len = array->len;
 
@@ -862,7 +875,7 @@ gjs_define_byte_array_stuff(JSContext      *context,
     gjs_byte_array_prototype = JS_InitClass(context, global,
                              NULL,
                              &gjs_byte_array_class,
-                             byte_array_constructor,
+                             gjs_byte_array_constructor,
                              0,
                              &gjs_byte_array_proto_props[0],
                              &gjs_byte_array_proto_funcs[0],
