@@ -80,15 +80,6 @@ gjs_##name##_constructor(JSContext  *context,           \
                          uintN       argc,              \
                          jsval      *vp)
 
-/**
- * GJS_NATIVE_CONSTRUCTOR_VARIABLES:
- * Declare variables necessary for the constructor; should
- * be at the very top.
- */
-#define GJS_NATIVE_CONSTRUCTOR_VARIABLES(name)          \
-    JSObject *object = NULL;                            \
-    jsval *argv = JS_ARGV(context, vp);
-
 /**
  * GJS_NATIVE_CONSTRUCTOR_PRELUDE:
  * Call after the initial variable declaration.
@@ -123,8 +114,6 @@ gjs_##name##_constructor(JSContext *context,            \
                          jsval     *argv,               \
                          jsval     *retval)
 
-#define GJS_NATIVE_CONSTRUCTOR_VARIABLES(name)
-
 #define GJS_NATIVE_CONSTRUCTOR_PRELUDE(name)            \
     if (!JS_IsConstructing(context)) {                  \
         gjs_throw_constructor_error(context);           \
@@ -135,6 +124,14 @@ gjs_##name##_constructor(JSContext *context,            \
 
 #endif
 
+#ifndef HAVE_JS_STRICTPROPERTYSTUB
+#define JS_StrictPropertyStub JS_PropertyStub
+#endif
+
+#ifndef HAVE_JS_GETGLOBALFORSCOPECHAIN
+#define JS_GetGlobalForScopeChain JS_GetScopeChain
+#endif
+
 G_END_DECLS
 
 #endif  /* __GJS_COMPAT_H__ */
