@@ -1708,7 +1708,7 @@ exports_new_resolve(JSContext *context,
  */
 GJS_NATIVE_CONSTRUCTOR_DECLARE(js_exports)
 {
-    GJS_NATIVE_CONSTRUCTOR_VARIABLES(js_exports)
+    JSObject *object = NULL;                            \
     Exports *priv;
 
     GJS_NATIVE_CONSTRUCTOR_PRELUDE(js_exports);
@@ -1803,7 +1803,7 @@ static struct JSClass gjs_js_exports_class = {
     JS_PropertyStub,
     JS_PropertyStub,
     JS_PropertyStub,
-    JS_PropertyStub,
+    JS_StrictPropertyStub,
     JS_EnumerateStub,
     (JSResolveOp) exports_new_resolve, /* needs cast since it's the new resolve signature */
     JS_ConvertStub,
